==> datatables-plugins-1.13.4.jar: META-INF/resources/webjars/datatables-plugins/1.13.4/i18n/bg.js <==
(function( factory ) {
	if ( typeof define === 'function' && define.amd ) {
		// AMD
		define( [], factory);
	}
	else if ( typeof exports === 'object' ) {
		// CommonJS
		module.exports = factory();
	}
	// No browser loader - use JSON, ESM, CJS or AMD
}
(function() {
    return {
    "processing": "Обработка на резултатите...",
    "lengthMenu": "Показване на _MENU_ резултата",
    "zeroRecords": "Няма намерени резултати",
    "info": "Показване на резултати от _START_ до _END_ от общо _TOTAL_",
    "infoEmpty": "Показване на резултати от 0 до 0 от общо 0",
    "infoFiltered": "(филтрирани от общо _MAX_ резултата)",
    "search": "Търсене:",
    "paginate": {
        "first": "Първа",
        "previous": "Предишна",
        "next": "Следваща",
        "last": "Последна"
    },
    "aria": {
        "sortAscending": "сортирай възходящо",
        "sortDescending": "сортирай низходящо"
    },
    "autoFill": {
        "cancel": "Oткажи",
        "fill": "Попълни всички клетки с <i>%d<i><\/i><\/i>",
        "fillHorizontal": "Попълни хоризонтални клетки",
        "fillVertical": "Попълни вертикални клетки"
    },
    "searchBuilder": {
        "add": "Добави",
        "deleteTitle": "Изтрий критериите за търсене",
        "clearAll": "Изчисти всичко",
        "condition": "Правило",
        "conditions": {
            "array": {
                "contains": "Съдържа",
                "empty": "Празно",
                "equals": "Еднакво с",
                "not": "Различно от",
                "notEmpty": "Не е празно",
                "without": "Без"
            },
            "date": {
                "after": "След",
                "before": "Преди",
                "between": "Между",
                "empty": "Празно",
                "equals": "Равна на",
                "not": "Различна от",
                "notBetween": "Не е между",
                "notEmpty": "Не е празно"
            },
            "number": {
                "between": "Между",
                "empty": "Празно",
                "equals": "Равно",
                "gt": "Над",
                "gte": "Над или равно",
                "lt": "Под",
                "lte": "Под или равно",
                "not": "Различно от",
                "notBetween": "Не е между",
                "notEmpty": "Не е празно"
            },
            "string": {
                "contains": "Съдържа",
                "empty": "Празно",
                "endsWith": "Завършва с",
                "equals": "Еднакво с",
                "not": "Различно от",
                "notEmpty": "Не е празно",
                "startsWith": "Започва с"
            }
        },
        "data": "Поле",
        "logicAnd": "И",
        "logicOr": "Или",
        "value": "Стойност"
    },
    "searchPanes": {
        "clearMessage": "Изтрий всички",
        "emptyPanes": "Няма SearchPanes",
        "loadMessage": "Зареждане...",
        "title": "Активни филтри - %d"
    },
    "buttons": {
        "collection": "Колекция",
        "colvis": "Показване\/Скриване на колони",
        "colvisRestore": "Показване на всички колони",
        "copy": "Копиране",
        "copyKeys": "Натисни <i>ctrl или u2318 + C за да копираш данните от таблицата.<br \/> За да отмените, щракнете върху това съобщение или натиснете <i>escape<\/i>.<\/i>",
        "copySuccess": {
            "_": "Копирани %ds реда",
            "1": "Копиран един ред"
        },
        "copyTitle": "Копиране в буфера",
        "pageLength": {
            "_": "Покажи %d реда",
            "-1": "Покажи всички редове"
        },
        "print": "Принтиране"
    },
    "datetime": {
        "hours": "Часове",
        "minutes": "Минути",
        "months": {
            "0": "Януари",
            "1": "Февруари",
            "10": "Ноември",
            "11": "Декември",
            "2": "Март",
            "3": "Април",
            "4": "Май",
            "5": "Юни",
            "6": "Юли",
            "7": "Август",
            "8": "Септември",
            "9": "Октомври"
        },
        "next": "Напред",
        "previous": "Назад",
        "seconds": "Секунди",
        "weekdays": [
            "Нед",
            "Пон",
            "Вт",
            "Ср",
            "Четв",
            "Пет",
            "Съб"
        ]
    },
    "editor": {
        "close": "Затвори",
        "create": {
            "button": "Нов запис",
            "submit": "Създай",
            "title": "Създай нов запис"
        },
        "edit": {
            "button": "Промени",
            "submit": "Промени",
            "title": "Промени запис"
        },
        "error": {
            "system": "Грешка в системата!"
        },
        "multi": {
            "info": "Избраните елементи съдържат различни стойности за това поле. За да редактирате и зададете всички елементи за това поле на една и съща стойност, щракнете или докоснете тук, в противен случай те ще запазят своите индивидуални стойности.",
            "noMulti": "Това полеможе да се редактира индивидуално, но не е част от група.",
            "restore": "Отмяна на промените",
            "title": "Множество стойности"
        },
        "remove": {
            "button": "Изтрий",
            "confirm": {
                "_": "Сигурни ли сте, че искате да изтриете %d реда?",
                "1": "Сигурни ли сте, че искате да изтриете 1 ред?"
            },
            "submit": "Изтрий",
            "title": "Изтрий запис"
        }
    },
    "emptyTable": "Няма налични данни в таблицата",
    "loadingRecords": "Зареждане...",
    "select": {
        "cells": {
            "_": "%d избрани клетки",
            "1": "%d избрана клетка"
        },
        "columns": {
            "_": "%d избрани колони",
            "1": "%d избрана колона"
        },
        "rows": {
            "_": "%d избрани реда",
            "1": "%d избран ред"
        }
    }
};
}));

==> datatables-plugins-1.13.5.jar: META-INF/resources/webjars/datatables-plugins/1.13.5/i18n/bg.js <==
(function( factory ) {
	if ( typeof define === 'function' && define.amd ) {
		// AMD
		define( [], factory);
	}
	else if ( typeof exports === 'object' ) {
		// CommonJS
		module.exports = factory();
	}
	// No browser loader - use JSON, ESM, CJS or AMD
}
(function() {
    return {
    "processing": "Обработка на резултатите...",
    "lengthMenu": "Показване на _MENU_ резултата",
    "zeroRecords": "Няма намерени резултати",
    "info": "Показване на резултати от _START_ до _END_ от общо _TOTAL_",
    "infoEmpty": "Показване на резултати от 0 до 0 от общо 0",
    "infoFiltered": "(филтрирани от общо _MAX_ резултата)",
    "search": "Търсене:",
    "paginate": {
        "first": "Първа",
        "previous": "Предишна",
        "next": "Следваща",
        "last": "Последна"
    },
    "aria": {
        "sortAscending": "сортирай възходящо",
        "sortDescending": "сортирай низходящо"
    },
    "autoFill": {
        "cancel": "Oткажи",
        "fill": "Попълни всички клетки с <i>%d<i><\/i><\/i>",
        "fillHorizontal": "Попълни хорЀзонтални клетки",
        "fillVertical": "Попълни вертикални клетки"
    },
    "searchBuilder": {
        "add": "Добави",
        "deleteTitle": "Изтрий критериите за търсене",
        "clearAll": "Изчисти всичко",
        "condition": "Правило",
        "conditions": {
            "array": {
                "contains": "Съдържа",
                "empty": "Празно",
                "equals": "Еднакво с",
                "not": "Различно от",
                "notEmpty": "Не е празно",
                "without": "Без"
            },
            "date": {
                "after": "След",
                "before": "Преди",
                "between": "Между",
                "empty": "Празно",
                "equals": "Равна на",
                "not": "Различна от",
                "notBetween": "Не е между",
                "notEmpty": "Не е празно"
            },
            "number": {
                "between": "Между",
                "empty": "Празно",
                "equals": "Равно",
                "gt": "Над",
                "gte": "Над или равно",
                "lt": "Под",
                "lte": "Под или равно",
                "not": "Различно от",
                "notBetween": "Не е между",
                "notEmpty": "Не е празно"
            },
            "string": {
                "contains": "Съдържа",
                "empty": "Празно",
                "endsWith": "Завършва с",
                "equals": "Еднакво с",
                "not": "Различно от",
                "notEmpty": "Не е празно",
                "startsWith": "Започва с"
            }
        },
        "data": "Поле",
        "logicAnd": "И",
        "logicOr": "Или",
        "value": "Стойност"
    },
    "searchPanes": {
        "clearMessage": "Изтрий всички",
        "emptyPanes": "Няма SearchPanes",
        "loadMessage": "Зареждане...",
        "title": "Активни филтри - %d"
    },
    "buttons": {
        "collection": "Колекция",
        "colvis": "Показване\/Скриване на колони",
        "colvisRestore": "Показване на всички колони",
        "copy": "Копиране",
        "copyKeys": "Натисни <i>ctrl или u2318 + C за да копираш данните от таблицата.<br \/> За да отмените, щракнете върху това съобщение или натиснете <i>escape<\/i>.<\/i>",
        "copySuccess": {
            "_": "Копирани %ds реда",
            "1": "Копиран един ред"
        },
        "copyTitle": "Копиране в буфера",
        "pageLength": {
            "_": "Покажи %d реда",
            "-1": "Покажи всички редове"
        },
        "print": "Принтиране"
    },
    "datetime": {
        "hours": "Часове",
        "minutes": "Минути",
        "months": {
            "0": "Януари",
            "1": "Февруари",
            "10": "Ноември",
            "11": "Декември",
            "2": "Март",
            "3": "Април",
            "4": "Май",
            "5": "Юни",
            "6": "Юли",
            "7": "АЀгуст",
            "8": "Септември",
            "9": "Октомври"
        },
        "next": "Напред",
        "previous": "Назад",
        "seconds": "Секунди",
        "weekdays": [
            "Нед",
            "Пон",
            "Вт",
            "Ср",
            "Четв",
            "Пет",
            "Съб"
        ]
    },
    "editor": {
        "close": "Затвори",
        "create": {
            "button": "Нов запис",
            "submit": "Създай",
            "title": "Създай нов запис"
        },
        "edit": {
            "button": "Промени",
            "submit": "Промени",
            "title": "Промени запис"
        },
        "error": {
            "system": "Грешка в системата!"
        },
        "multi": {
            "info": "Избраните елементи съдържат различни стойности за това поле. За да реЀактирате и зададете всички елементи за това поле на една и съща стойност, щракнете или докоснете тук, в противен случай те ще запазят своите индивидуални стойности.",
            "noMulti": "Това полеможе да се редактира индивидуално, но не е част от група.",
            "restore": "Отмяна на промените",
            "title": "Множество стойности"
        },
        "remove": {
            "button": "Изтрий",
            "confirm": {
                "_": "Сигурни ли сте, че искате да изтриете %d реда?",
                "1": "Сигурни ли сте, че искате да изтриете 1 ред?"
            },
            "submit": "Изтрий",
            "title": "Изтрий запис"
        }
    },
    "emptyTable": "Няма наЀични данни в таблицата",
    "loadingRecords": "Зареждане...",
    "select": {
        "cells": {
            "_": "%d избрани клетки",
            "1": "%d избрана клетка"
        },
        "columns": {
            "_": "%d избрани колони",
            "1": "%d избрана колона"
        },
        "rows": {
            "_": "%d избрани реда",
            "1": "%d избран ред"
        }
    }
};
}));
